@@ -23,7 +23,7 @@ const extension: JupyterFrontEndPlugin<void> = {
                 "closeButton": true,
                 "newestOnTop": true,
                 "progressBar": true,
-                "positionClass": "toast-top-right",
+                "positionClass": "toast-bottom-right",
                 "preventDuplicates": false,
                 "onclick": null,
                 "showDuration": 30,
